@@ -65,8 +65,8 @@ fn tree_basics<Root: nebari::tree::Root, File: ManagedFile>(
     tree: &mut TreeFile<Root, File>,
 ) -> Result<(), Error> {
     // Insert a few key-value pairs.
-    tree.push(None, ArcBytes::from(b"a key"), ArcBytes::from(b"a value"))?;
-    tree.push(None, ArcBytes::from(b"b key"), ArcBytes::from(b"b value"))?;
+    tree.set(None, ArcBytes::from(b"a key"), ArcBytes::from(b"a value"))?;
+    tree.set(None, ArcBytes::from(b"b key"), ArcBytes::from(b"b value"))?;
     // Retrieve a value.
     let value = tree.get(b"a key", false)?.unwrap();
     assert_eq!(value, b"a value");
@@ -85,7 +85,7 @@ fn tree_basics<Root: nebari::tree::Root, File: ManagedFile>(
     )?;
 
     // Replace the value for "a key"
-    tree.push(
+    tree.set(
         None,
         ArcBytes::from(b"a key"),
         ArcBytes::from(b"a new value"),
