@@ -24,14 +24,14 @@ pub mod transaction;
 pub mod tree;
 mod vault;
 
-mod buffer;
 mod chunk_cache;
 mod context;
 #[cfg(test)]
 mod test_util;
 
+pub use arc_bytes::ArcBytes;
+
 pub use self::{
-    buffer::Buffer,
     chunk_cache::ChunkCache,
     context::Context,
     error::{Error, ErrorKind},
